Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(188)

Unified Diff: chrome/browser/profiles/profile_impl.cc

Issue 3326010: Linux: detect the native (encrypted) password store to use by default. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/profiles/profile_impl.cc
===================================================================
--- chrome/browser/profiles/profile_impl.cc (revision 70264)
+++ chrome/browser/profiles/profile_impl.cc (working copy)
@@ -466,8 +466,8 @@
// DownloadManager is lazily created, so check before accessing it.
if (download_manager_.get()) {
- // The download manager queries the history system and should be shutdown
- // before the history is shutdown so it can properly cancel all requests.
+ // The download manager queries the history system and should be shut down
+ // before the history is shut down so it can properly cancel all requests.
download_manager_->Shutdown();
download_manager_ = NULL;
}
@@ -923,7 +923,7 @@
#elif defined(OS_POSIX)
// On POSIX systems, we try to use the "native" password management system of
// the desktop environment currently running, allowing GNOME Keyring in XFCE.
// (In all cases we fall back on the default store in case of failure.)
base::nix::DesktopEnvironment desktop_env;
std::string store_type =
CommandLine::ForCurrentProcess()->GetSwitchValueASCII(
@@ -932,16 +932,13 @@
desktop_env = base::nix::DESKTOP_ENVIRONMENT_KDE4;
} else if (store_type == "gnome") {
desktop_env = base::nix::DESKTOP_ENVIRONMENT_GNOME;
- } else if (store_type == "detect") {
+ } else if (store_type == "basic") {
+ desktop_env = base::nix::DESKTOP_ENVIRONMENT_OTHER;
+ } else { // Detect the store to use automatically.
scoped_ptr<base::Environment> env(base::Environment::Create());
desktop_env = base::nix::GetDesktopEnvironment(env.get());
VLOG(1) << "Password storage detected desktop environment: "
<< base::nix::GetDesktopEnvironmentName(desktop_env);
- } else {
- // TODO(mdm): If the flag is not given, or has an unknown value, use the
- // default store for now. Once we're confident in the other stores, we can
- // default to detecting the desktop environment instead.
- desktop_env = base::nix::DESKTOP_ENVIRONMENT_OTHER;
}
scoped_ptr<PasswordStoreX::NativeBackend> backend;
@@ -964,9 +961,11 @@
backend.reset();
#endif // defined(USE_GNOME_KEYRING)
}
- // TODO(mdm): this can change to a WARNING when we detect by default.
- if (!backend.get())
- VLOG(1) << "Using default (unencrypted) store for password storage.";
+ if (!backend.get()) {
+ LOG(WARNING) << "Using basic (unencrypted) store for password storage. "
+ "See http://code.google.com/p/chromium/wiki/LinuxPasswordStorage for "
+ "more information about password storage options.";
+ }
ps = new PasswordStoreX(login_db, this,
GetWebDataService(Profile::IMPLICIT_ACCESS),
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -923,7 +923,7 @@
// On POSIX systems, we try to use the "native" password management system of
// the desktop environment currently running, allowing GNOME Keyring in XFCE.
- // (In all cases we fall back on the default store in case of failure.)
+ // (In all cases we fall back on the basic store in case of failure.)
base::nix::DesktopEnvironment desktop_env;
std::string store_type =

Powered by Google App Engine
This is Rietveld 408576698